@@ -1,4 +1,5 @@
 from flask import Blueprint, render_template, current_app
+from utils import diags
 import sys
 
 errors = Blueprint('errors', __name__)
@@ -23,4 +24,5 @@ def page_not_found_500(error):
     import traceback
     trace = traceback.format_exc()
     return render_template('errors/500.html', error=error, traceback=trace,
-                           current_app=current_app), 500
+                           current_app=current_app,
+                           diags=diags(error)), 500
